<script setup>
import AppLayoutCity from '@/Layouts/AppLayoutCity.vue';
import { Link } from '@inertiajs/inertia-vue3';
import DK_Input from '@/components/dk_Input.vue';
import { axiosApiCalls } from '../../../public/libs/datakorumJS';

</script>
<style>


.dataTables_filter{
  visibility: hidden;
  height: 0;
}

table {
  border-color: transparent !important;
}

table.dataTable thead .sorting {
  background-image: none !important;
}

table.dataTable thead .sorting_asc,
table.dataTable thead .sorting_desc {
  background-image: none !important;
  color: white !important;
  font-weight: 600 !important;
}

.dataTables_wrapper {
  margin-bottom: 0.5rem !important;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:active {
  cursor: default;
  color: rgba(200, 200, 200, 0.9) !important;
  border: 1px solid transparent;
  background: transparent;
  box-shadow: none;
}

.dataTables_wrapper .dataTables_paginate .paginate_button {
  box-sizing: border-box;
  display: inline-block;
  min-width: 1.5em;
  padding: 0.5em 1em;
  margin-left: 2px;
  text-align: center;
  text-decoration: none !important;
  cursor: pointer;
  cursor: hand;
  color: rgba(200, 200, 200, 0.9) !important;
  border: 0;
  border-radius: 0.375rem;
}

.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
  color: rgba(200, 200, 200, 1) !important;
  background-color: rgba(0, 152, 219, 0.1) !important;
  background-image: unset !important;
  border: 0;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.current,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:hover {
  color: rgba(255, 250, 250, 1) !important;
  border: 0 !important;
  background-color: rgba(0, 152, 219, 0.2) !important;
  background-image: unset !important;
  border-bottom-width: 2px;
  border-bottom-color: rgba(255, 250, 250, 1);
  border-radius: 0.375rem;
}

.dataTable thead th,
.dataTable thead td {
  padding-top: 0 !important;
  padding-bottom: 0 !important;
}

table.dataTable thead th,
table.dataTable thead td {
  padding: 0px 10px;
  font-size: 0.9rem !important;
  border-bottom: 1px solid rgba(200, 200, 200, 0.75) !important;
}

</style>
<template>
  <AppLayoutCity title="Devices">
    <loader-component></loader-component>

    <Link id="idMeterReadings" class="h-0 w-0 invisible" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityReadings', { idDevice: this.Meteriddevice, busIdDevice: this.MeterBUS_iddevice })"></Link>
    <Link id="idMeterProfile" class="h-0 w-0 invisible" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('profile', { id: this.Meteriddevice, busIdDevice: this.MeterBUS_iddevice })"></Link>

    <div style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background px-6 py-4 z-0 cursor-default flex flex-row gap-4">
        <div :class="{'!w-1/2': this.deviceSelected}" class="w-full py-4 px-6 baltoro-container">

            <div class="w-full flex flex-row justify-between items-center pb-2">
                <p class="text-white-snow font-light text-left text-2xl">{{ this.group_info[0].name }}</p>
                <div class="flex flex-row justify-end gap-4 items-center">
                    <DK_Input id="searchInput" type="text" textPosition="left" value="" :border="true" width="15rem" :placeholder="this.$t('general.Search') + '...'"></DK_Input>
                </div>
            </div>

            <table id="basicTable" class="row-border">
                <thead class="bg-transparent text-gray-light my-2">
                    <tr>
                        <th>{{ this.$t("general.GatewayID") }}</th>
                        <th>{{ this.$t("general.Version") }}</th>
                        <th>{{ this.$t("general.Name") }}</th>
                        <th class="w-[12rem]">{{ this.$t("general.Readings") }}</th>
                        <th class="w-[12rem]" v-if="!this.checkPark(true)">{{ this.$t("general.Profile") }}</th>
                        <th class="w-[0rem]" v-else></th>
                        <th class="w-[12rem]" v-if="!this.checkPark(true) && !this.checkMBUS(true)">{{ this.$t("general.Dashboard") }}</th>
                        <th class="w-[0rem]" v-else></th>
                        <th class="w-5"></th>
                    </tr>
                </thead>
                <tbody class="text-center">
                    <tr class="items-center" v-for="(data, index) in this.gateways" :key="index" @click="selectDevice(this.gateways[index].id)"
                    :class="{
                        'bg-transparent': !(this.hasAlert(this.gateways[index].id)),
                        'bg-yellow-alert-opa hover:bg-yellow-alert-opa-hover': this.hasAlert(this.gateways[index].id),
                        'hidden': this.gateways[index].solutions_id == null,
                        '!bg-cyan-opa': this.gateways[index].id == this.deviceSelected,
                        'cursor-pointer': checkMBUS(this.gateways[index].id)
                    }">
                        <td>{{ this.gateways[index].id }}</td> <!-- GatewayID -->
                        <td>{{ this.gateways[index].type_name }}</td> <!-- Version -->
                        <td>{{ this.gateways[index].name }}</td> <!-- Name -->
                        <td v-if="!checkMBUS(this.gateways[index].id)" class="w-fit"> <!-- Readings -->
                            <div class="flex items-center justify-center px-1 py-0.5 w-full">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityReadings', { idDevice:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-chart-column" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else></td>

                        <td v-if="!this.checkPark(this.gateways[index].id) && !checkMBUS(this.gateways[index].id)" class="w-fit"> <!-- Profile -->
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnProfile">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('profile', { id:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-gears" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else></td>

                        <td v-if="this.ScreenDisplay(this.gateways[index]) == 'vacon'">
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnVacon">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('vacon', { id: this.gateways[index].id, page: 1 })">
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm text-center inline-flex justify-center items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-box" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else-if="this.ScreenDisplay(this.gateways[index]) == 'meteo'">
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnMeteo">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('meteo', { id:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm text-center inline-flex justify-center items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-cloud-sun" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else-if="this.ScreenDisplay(this.gateways[index]) == 'valve'">
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnValve">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('valve', { id:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm text-center inline-flex justify-center items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-cloud-sun" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else-if="this.ScreenDisplay(this.gateways[index]) == 'rtdashboard'">
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnRTdashboard">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('rtDashboard', { id:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm text-center inline-flex justify-center items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-bolt" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else-if="this.ScreenDisplay(this.gateways[index]) == 'optidrive'">
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnOptidrive">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('optidrive', { id:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm text-center inline-flex justify-center items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-bolt" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else-if="this.ScreenDisplay(this.gateways[index]) == 'wilo'">
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnWilo">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('wilo', { id:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm text-center inline-flex justify-center items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-gauge-high" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else-if="this.ScreenDisplay(this.gateways[index]) == 'ullastres'">
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnUllastres">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('ullastres', { id:  this.gateways[index].id })" >
                                <button type="button"
                                class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm text-center inline-flex justify-center items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                <i class="fa-solid fa-droplet" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                            </div>
                        </td>

                        <td v-else-if="this.ScreenDisplay(this.gateways[index]) == null"></td>

                        <td class="w-5" v-if="this.hasAlert(this.gateways[index].id)">
                            <i class="fa-solid fa-triangle-exclamation" style="font-size:1rem; color:rgba(224,191,52,1);"></i>
                        </td>

                        <td class="w-5" v-else></td>

                    </tr>
                </tbody>
            </table>
        </div>
        <div :class="{'hidden': !this.checkMBUS() || !this.deviceSelected}" class="w-1/2 py-4 px-6 baltoro-container">
            <div class="w-full flex flex-row justify-between items-start pb-2">
                <p v-if="this.deviceSelected" class="text-white-snow font-light text-left text-2xl">{{ this.$t('general.Meters') + ' - ' + this.gateways.find(gateway => gateway.id === this.deviceSelected).name }}</p>
                <i @click="unselectDevice()" class="fa-solid fa-xmark pt-2 cursor-pointer text-white-snow/60 hover:text-white-snow" style="font-size:1rem"></i>
            </div>

            <table id="meterTable" class="row-border">
                <thead class="bg-transparent text-gray-light my-2">
                    <tr>
                        <th>{{ this.$t("general.Meter Id") }}</th>
                        <th>{{ this.$t("general.Meter Model") }}</th>
                        <th class="w-[12rem]">{{ this.$t("general.Readings") }}</th>
                        <th class="w-[12rem]">{{ this.$t("general.Profile") }}</th>
                    </tr>
                </thead>
                <tbody class="text-center">
                    <tr class="items-center" v-for="(meter, index) in this.meters" :key="index">
                        <td>{{meter.BUS_iddevice}}</td>
                        <td>{{(meter.BUS_Device_Model ? meter.BUS_Device_Model : '')}}</td>
                        <td class="w-fit"> <!-- Readings -->
                            <div class="flex items-center justify-center px-1 py-0.5 w-full">
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" href="" >
                                    <button type="button"
                                    class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                    <i class="fa-solid fa-chart-column" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                    </button>
                                </Link>
                            </div>
                        </td>

                        <td class="w-fit"> <!-- Profile -->
                            <div class="flex items-center justify-center px-1 py-0.5 w-full" id="btnProfile">
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" href="" >
                                    <button type="button"
                                    class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                    <i class="fa-solid fa-gears" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                    </button>
                                </Link>
                            </div>
                        </td>
                    </tr>
                </tbody>
            </table>
        </div>
    </div>
  </AppLayoutCity>
</template>

<script>

export default {

  data() {
    return {
        screen_width: 0,
        GW_open: new Array(this.gateways.length).fill(false),
        deviceSelected: null,
        meters: [],
        Meteriddevice: '',
        MeterBUS_iddevice: '',
    };
  },

  props: ['gateways', 'group_info', 'alerts_log', 'user'],

  beforeCreate() {

    this.$i18n.locale = this.user.language

    localStorage.setItem("Back", "devices");

    localStorage.setItem("Alerts", 0);

    for (var index = 0; index < this.alerts_log.length; index++) {
      if (this.alerts_log[index].read == 0) {
        localStorage.setItem("Alerts", +localStorage.getItem("Alerts") + 1);
      }
    }

    if (+localStorage.getItem("Alerts") > 9) {
      localStorage.setItem("Alerts", '9+');
    }
  },

  beforeMount() {
    this.screen_width = window.screen.width;
  },

  mounted() {
    window.emitter.emit('changeLoaderStatus', false, 'orbit')

    this.table = $("#basicTable").DataTable({
        language: {
            url: "/assets/i18n/" + this.user.language + ".json",
        },
        order: (this.screen_width >= 768) ? [[2, "asc"]] : [[1, "asc"]],
        searching: true,
        info: true,
        paging: false,
        scrollY: (this.screen_width >= 768) ? 'calc(100vh - 16rem)' : 'calc(100vh - 11.5rem)',
    });

    this.meterTable = $("#meterTable").DataTable({
        language: {
            url: "/assets/i18n/" + this.user.language + ".json",
        },
        order: [[0, "asc"]],
        searching: true,
        info: true,
        paging: false,
        scrollY: (this.screen_width >= 768) ? 'calc(100vh - 16rem)' : 'calc(100vh - 11.5rem)',
    });

    const self = this;  // Almacenamos una referencia a "this" para su uso dentro del manejador

    // Vincular el campo de búsqueda personalizado con DataTables
    $('#searchInput').on('keyup', function() {
        const searchTerm = this.value;
        self.table.search(searchTerm);
        self.table.draw();  // Actualiza la tabla después de la búsqueda
    });
  },

  methods: {

    selectDevice(iddevice){

        const gateway = this.gateways.find(gateway => gateway.id === iddevice)

        if(this.deviceSelected != iddevice && this.checkMBUS(iddevice)){
            this.deviceSelected = iddevice

            axiosApiCalls.methodGet('/meters/get/'+this.user.id+'/'+iddevice, this.user.token)
                .then( (meters) => {

                    this.meterTable.clear();

                    let idBUS_iddevice = new Array();

                    meters.forEach((meter, index) => {

                        idBUS_iddevice[index] = iddevice + '.' +meter.BUS_iddevice

                        let temp_row = ['<td>' + meter.BUS_iddevice + '</td>'];

                        temp_row.push('<td>' + (meter.BUS_Device_Model ? meter.BUS_Device_Model : '') + '</td>');

                        temp_row.push(
                        '<td>' +
                            '<div class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 cursor-pointer" id="btnReadings_' + idBUS_iddevice[index] + '">' +
                                '<i class="fa-solid fa-chart-column" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            "</div>" +
                        '</td>');

                        temp_row.push(
                        '<td>' +
                            '<div class="w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 cursor-pointer" id="btnProfile_' + idBUS_iddevice[index] + '">' +
                                '<i class="fa-solid fa-gears" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            "</div>" +
                        '</td>');

                        temp_row.push('<td></td>');

                        if (temp_row.length > 1)
                            this.meterTable.row.add(temp_row).draw(false);
                    })

                    setTimeout(() => {
                        this.createButtons(idBUS_iddevice)
                    }, 0);

                });
        }
    },

    unselectDevice(){
        this.deviceSelected = null

        setTimeout(() => {
            this.table.draw()
        }, 0);
    },

    createButtons(meterList){
        const buttonOptions = ['btnReadings_', 'btnProfile_']

        buttonOptions.forEach((option) => {
            meterList.forEach((meterIdentifier) => {
                const button = document.getElementById(option + meterIdentifier)

                if(button){
                    button.addEventListener("click", () => {
                        const identifier = meterIdentifier.split('.');

                        const iddevice = identifier[0];
                        const BUS_iddevice = identifier[1];

                        this.Meteriddevice = iddevice
                        this.MeterBUS_iddevice = BUS_iddevice

                        if(option === 'btnReadings_'){
                            setTimeout(() => {document.getElementById('idMeterReadings').click();}, 0);
                        } else if(option === 'btnProfile_'){
                            setTimeout(() => {document.getElementById('idMeterProfile').click();}, 0);
                        }
                    });
                }
            })
        })
    },

    hasAlert(iddevice) {
      for (var index = 0; index < this.alerts_log.length; index++) {
        if (this.alerts_log[index].iddevice == iddevice && this.alerts_log[index].read == 0) {
          return true;
        }
      }
      return false;
    },

    checkPark(checker) {
        if(checker){
            let checker = true
            for (let i = 0; i < this.gateways.length; i++) {
                if (this.gateways[i].type_name.indexOf('PARK') == -1) {
                    checker = false
                }
            }
            return checker
        }

        const gateway = this.gateways.find(gateway => gateway.id === checker)

        if(gateway) {
            if (gateway.type_name.indexOf('PARK') != -1) {
                return true
            } else {
                return false
            }
        }

        for (let i = 0; i < this.gateways.length; i++) {
            if (this.gateways[i].type_name.indexOf('PARK') !== -1) {
                return true;
            }
        }
        return false;
    },

    checkMBUS(checker){
        if(checker === true){
            let checker = true
            for (let i = 0; i < this.gateways.length; i++) {
                if (this.gateways[i].type_name.indexOf('MB') == -1 && this.gateways[i].type_name.indexOf('WM') == -1) {
                    checker = false
                }
            }
            return checker
        }

        const gateway = this.gateways.find(gateway => gateway.id === checker)

        if(gateway) {
            if (gateway.type_name.indexOf('MB') != -1 || gateway.type_name.indexOf('WM') != -1) {
                return true
            } else {
                return false
            }
        }

        for (let i = 0; i < this.gateways.length; i++) {
            if (this.gateways[i].type_name.indexOf('MB') !== -1 || this.gateways[i].type_name.indexOf('WM') !== -1) {
                return true;
            }
        }
        return false;
    },

    ScreenDisplay(gateway){

      let screen;

      if(gateway.MODBUS_device_type && (gateway.MODBUS_device_type == 6 || gateway.MODBUS_device_type == 7)) {
        screen = 'vacon';
      } else if(gateway.MODBUS_device_type && (gateway.MODBUS_device_type == 23)) {
        screen = 'rtdashboard'
      } else if(gateway.MODBUS_device_type && (gateway.MODBUS_device_type == 34)) {
        screen = 'optidrive'
      } else if(gateway.MODBUS_device_type && (gateway.MODBUS_device_type == 31)) {
        screen = 'wilo'
      } else if(gateway.solutions_id && gateway.solutions_id == 8) {
        screen = 'meteo';
      } else if(gateway.solutions_id && gateway.solutions_id == 9) {
        screen = 'valve';
      } else if(gateway.solutions_id && gateway.solutions_id == 11) {
        screen = 'ullastres';
      } else {
        screen = null;
      }

      return screen;
    },

    OpenRow(index){
        this.GW_open[index] = !this.GW_open[index];
    },

  },
}
</script>



